@@ -103,6 +103,29 @@ EOH
 
 Returns a "report_bugs_to" key in the payload, containing the address to
 report bugs to.
+EOH
+    },
+    'dbstatus' =>
+    {
+        target => {
+            GET => '_get_dbstatus',
+        },
+        target_module => 'App::Dochazka::REST::Dispatch',
+        acl_profile => 'inactive',
+        cli => 'dbstatus',
+        description => 'Display status of database connection',
+        documentation => <<'EOH',
+=pod
+
+This resource checks the employee's database connection and reports on its status.
+The result - either "UP" or "DOWN" - will be encapsulated in a payload like this:
+
+    { "dbstatus" : "UP" }
+
+Each employee gets her own database connection when she logs in to Dochazka.
+Calling this resource causes the server to execute a 'ping' on the connection.
+If the ping test fails, the server will attempt to open a new connection. Only
+if this, too, fails will "DOWN" be returned.
 EOH
     },
     'docu' => 
