@@ -35,7 +35,7 @@
 
 # DOCHAZKA_DOCGEN_COPYRIGHT_NOTICE
 #     the copyright notice
-set( 'DOCHAZKA_DOCGEN_COPYRIGHT_NOTICE', <<'EOH' );
+set( 'DOCHAZKA_DOCGEN_COPYRIGHT_NOTICE', <<'EOHC' );
 # ************************************************************************* 
 # Copyright (c) 2014, SUSE LLC
 # 
@@ -67,20 +67,18 @@ set( 'DOCHAZKA_DOCGEN_COPYRIGHT_NOTICE', <<'EOH' );
 # ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 # POSSIBILITY OF SUCH DAMAGE.
 # ************************************************************************* 
-EOH
+EOHC
 
 # DOCHAZKA_DOCGEN_PREAMBLE
 #     preamble of Resources.pm, which is generated by docgen.sh
-set( 'DOCHAZKA_DOCGEN_PREAMBLE', <<'EOH' );
+set( 'DOCHAZKA_DOCGEN_PREAMBLE', <<'EOHP' );
 package App::Dochazka::REST::Docs::Resources;
 
 use 5.012;
 use strict;
 use warnings FATAL => 'all';
 
-use App::Dochazka::REST;
-
-EOH
+EOHP
 
 # DOCHAZKA_DOCGEN_POD_PREAMBLE
 #     preamble of Resources.pm, which is generated by docgen.sh
@@ -88,7 +86,7 @@ set( 'DOCHAZKA_DOCGEN_POD_PREAMBLE', <<'EOHG' );
 
 =head1 NAME
 
-App::Dochazka::REST::Docs::Resources - Documentation of App::Dochazka::REST resources
+App::Dochazka::REST::Docs::Resources - Documentation of REST resources
 
 
 =head1 DESCRIPTION
@@ -96,12 +94,19 @@ App::Dochazka::REST::Docs::Resources - Documentation of App::Dochazka::REST reso
 This is a POD-only module containing documentation on all the REST resources 
 defined under C<config/dispatch>. This module is auto-generated.
 
+
+=head1 RESOURCES
+
 EOHG
 
 # DOCHAZKA_DOCGEN_EPITAPH
 #     the last bit of Resources.pm, which is generated by docgen.sh
 set( 'DOCHAZKA_DOCGEN_EPITAPH', <<'EOHI' );
 
+=head1 AUTHOR
+
+Nathan Cutler C<ncutler@suse.cz>
+
 =cut
 EOHI
 
